@@ -2,7 +2,7 @@ static char const G_line[] =
 {
   '#',' ','C','o','n','f','i','g','u','r','a','t','i','o','n',' ','f','i','l','e',' ','f','o','r',' ','d','i','r','c','o','l','o','r','s',',',' ','a',' ','u','t','i','l','i','t','y',' ','t','o',' ','h','e','l','p',' ','y','o','u',' ','s','e','t',' ','t','h','e',0,
   '#',' ','L','S','_','C','O','L','O','R','S',' ','e','n','v','i','r','o','n','m','e','n','t',' ','v','a','r','i','a','b','l','e',' ','u','s','e','d',' ','b','y',' ','G','N','U',' ','l','s',' ','w','i','t','h',' ','t','h','e',' ','-','-','c','o','l','o','r',' ','o','p','t','i','o','n','.',0,
-  '#',' ','C','o','p','y','r','i','g','h','t',' ','(','C',')',' ','1','9','9','6',',',' ','1','9','9','9','-','2','0','0','7',0,
+  '#',' ','C','o','p','y','r','i','g','h','t',' ','(','C',')',' ','1','9','9','6',',',' ','1','9','9','9','-','2','0','0','8',0,
   '#',' ','F','r','e','e',' ','S','o','f','t','w','a','r','e',' ','F','o','u','n','d','a','t','i','o','n',',',' ','I','n','c','.',0,
   '#',' ','C','o','p','y','i','n','g',' ','a','n','d',' ','d','i','s','t','r','i','b','u','t','i','o','n',' ','o','f',' ','t','h','i','s',' ','f','i','l','e',',',' ','w','i','t','h',' ','o','r',' ','w','i','t','h','o','u','t',' ','m','o','d','i','f','i','c','a','t','i','o','n',',',0,
   '#',' ','a','r','e',' ','p','e','r','m','i','t','t','e','d',' ','p','r','o','v','i','d','e','d',' ','t','h','e',' ','c','o','p','y','r','i','g','h','t',' ','n','o','t','i','c','e',' ','a','n','d',' ','t','h','i','s',' ','n','o','t','i','c','e',' ','a','r','e',' ','p','r','e','s','e','r','v','e','d','.',0,
@@ -29,6 +29,7 @@ static char const G_line[] =
   'T','E','R','M',' ','e','t','e','r','m','-','c','o','l','o','r',0,
   'T','E','R','M',' ','g','n','o','m','e',0,
   'T','E','R','M',' ','g','n','o','m','e','-','2','5','6','c','o','l','o','r',0,
+  'T','E','R','M',' ','j','f','b','t','e','r','m',0,
   'T','E','R','M',' ','k','o','n','s','o','l','e',0,
   'T','E','R','M',' ','k','t','e','r','m',0,
   'T','E','R','M',' ','l','i','n','u','x',0,
@@ -60,8 +61,9 @@ static char const G_line[] =
   '#',' ','3','0','=','b','l','a','c','k',' ','3','1','=','r','e','d',' ','3','2','=','g','r','e','e','n',' ','3','3','=','y','e','l','l','o','w',' ','3','4','=','b','l','u','e',' ','3','5','=','m','a','g','e','n','t','a',' ','3','6','=','c','y','a','n',' ','3','7','=','w','h','i','t','e',0,
   '#',' ','B','a','c','k','g','r','o','u','n','d',' ','c','o','l','o','r',' ','c','o','d','e','s',':',0,
   '#',' ','4','0','=','b','l','a','c','k',' ','4','1','=','r','e','d',' ','4','2','=','g','r','e','e','n',' ','4','3','=','y','e','l','l','o','w',' ','4','4','=','b','l','u','e',' ','4','5','=','m','a','g','e','n','t','a',' ','4','6','=','c','y','a','n',' ','4','7','=','w','h','i','t','e',0,
-  'N','O','R','M','A','L',' ','0','0',' ','#',' ','g','l','o','b','a','l',' ','d','e','f','a','u','l','t',',',' ','a','l','t','h','o','u','g','h',' ','e','v','e','r','y','t','h','i','n','g',' ','s','h','o','u','l','d',' ','b','e',' ','s','o','m','e','t','h','i','n','g','.',0,
-  'F','I','L','E',' ','0','0',' ','#',' ','n','o','r','m','a','l',' ','f','i','l','e',0,
+  '#','N','O','R','M','A','L',' ','0','0',' ','#',' ','n','o',' ','c','o','l','o','r',' ','c','o','d','e',' ','a','t',' ','a','l','l',0,
+  '#','F','I','L','E',' ','0','0',' ','#',' ','r','e','g','u','l','a','r',' ','f','i','l','e',':',' ','u','s','e',' ','n','o',' ','c','o','l','o','r',' ','a','t',' ','a','l','l',0,
+  'R','E','S','E','T',' ','0',' ','#',' ','r','e','s','e','t',' ','t','o',' ','"','n','o','r','m','a','l','"',' ','c','o','l','o','r',0,
   'D','I','R',' ','0','1',';','3','4',' ','#',' ','d','i','r','e','c','t','o','r','y',0,
   'L','I','N','K',' ','0','1',';','3','6',' ','#',' ','s','y','m','b','o','l','i','c',' ','l','i','n','k','.',' ','(','I','f',' ','y','o','u',' ','s','e','t',' ','t','h','i','s',' ','t','o',' ','\'','t','a','r','g','e','t','\'',' ','i','n','s','t','e','a','d',' ','o','f',' ','a',0,
   ' ','#',' ','n','u','m','e','r','i','c','a','l',' ','v','a','l','u','e',',',' ','t','h','e',' ','c','o','l','o','r',' ','i','s',' ','a','s',' ','f','o','r',' ','t','h','e',' ','f','i','l','e',' ','p','o','i','n','t','e','d',' ','t','o','.',')',0,
@@ -73,6 +75,7 @@ static char const G_line[] =
   'O','R','P','H','A','N',' ','4','0',';','3','1',';','0','1',' ','#',' ','s','y','m','l','i','n','k',' ','t','o',' ','n','o','n','e','x','i','s','t','e','n','t',' ','f','i','l','e',',',' ','o','r',' ','n','o','n','-','s','t','a','t','\'','a','b','l','e',' ','f','i','l','e',0,
   'S','E','T','U','I','D',' ','3','7',';','4','1',' ','#',' ','f','i','l','e',' ','t','h','a','t',' ','i','s',' ','s','e','t','u','i','d',' ','(','u','+','s',')',0,
   'S','E','T','G','I','D',' ','3','0',';','4','3',' ','#',' ','f','i','l','e',' ','t','h','a','t',' ','i','s',' ','s','e','t','g','i','d',' ','(','g','+','s',')',0,
+  'C','A','P','A','B','I','L','I','T','Y',' ','3','0',';','4','1',' ','#',' ','f','i','l','e',' ','w','i','t','h',' ','c','a','p','a','b','i','l','i','t','y',0,
   'S','T','I','C','K','Y','_','O','T','H','E','R','_','W','R','I','T','A','B','L','E',' ','3','0',';','4','2',' ','#',' ','d','i','r',' ','t','h','a','t',' ','i','s',' ','s','t','i','c','k','y',' ','a','n','d',' ','o','t','h','e','r','-','w','r','i','t','a','b','l','e',' ','(','+','t',',','o','+','w',')',0,
   'O','T','H','E','R','_','W','R','I','T','A','B','L','E',' ','3','4',';','4','2',' ','#',' ','d','i','r',' ','t','h','a','t',' ','i','s',' ','o','t','h','e','r','-','w','r','i','t','a','b','l','e',' ','(','o','+','w',')',' ','a','n','d',' ','n','o','t',' ','s','t','i','c','k','y',0,
   'S','T','I','C','K','Y',' ','3','7',';','4','4',' ','#',' ','d','i','r',' ','w','i','t','h',' ','t','h','e',' ','s','t','i','c','k','y',' ','b','i','t',' ','s','e','t',' ','(','+','t',')',' ','a','n','d',' ','n','o','t',' ','o','t','h','e','r','-','w','r','i','t','a','b','l','e',0,
@@ -94,7 +97,6 @@ static char const G_line[] =
   ' ','#',' ','a','r','c','h','i','v','e','s',' ','o','r',' ','c','o','m','p','r','e','s','s','e','d',' ','(','b','r','i','g','h','t',' ','r','e','d',')',0,
   '.','t','a','r',' ','0','1',';','3','1',0,
   '.','t','g','z',' ','0','1',';','3','1',0,
-  '.','s','v','g','z',' ','0','1',';','3','1',0,
   '.','a','r','j',' ','0','1',';','3','1',0,
   '.','t','a','z',' ','0','1',';','3','1',0,
   '.','l','z','h',' ','0','1',';','3','1',0,
@@ -131,6 +133,8 @@ static char const G_line[] =
   '.','t','i','f',' ','0','1',';','3','5',0,
   '.','t','i','f','f',' ','0','1',';','3','5',0,
   '.','p','n','g',' ','0','1',';','3','5',0,
+  '.','s','v','g',' ','0','1',';','3','5',0,
+  '.','s','v','g','z',' ','0','1',';','3','5',0,
   '.','m','n','g',' ','0','1',';','3','5',0,
   '.','p','c','x',' ','0','1',';','3','5',0,
   '.','m','o','v',' ','0','1',';','3','5',0,
@@ -152,11 +156,17 @@ static char const G_line[] =
   '.','f','l','c',' ','0','1',';','3','5',0,
   '.','a','v','i',' ','0','1',';','3','5',0,
   '.','f','l','i',' ','0','1',';','3','5',0,
+  '.','f','l','v',' ','0','1',';','3','5',0,
   '.','g','l',' ','0','1',';','3','5',0,
   '.','d','l',' ','0','1',';','3','5',0,
   '.','x','c','f',' ','0','1',';','3','5',0,
   '.','x','w','d',' ','0','1',';','3','5',0,
   '.','y','u','v',' ','0','1',';','3','5',0,
+  '#',' ','h','t','t','p',':','/','/','w','i','k','i','.','x','i','p','h','.','o','r','g','/','i','n','d','e','x','.','p','h','p','/','M','I','M','E','_','T','y','p','e','s','_','a','n','d','_','F','i','l','e','_','E','x','t','e','n','s','i','o','n','s',0,
+  '.','a','x','v',' ','0','1',';','3','5',0,
+  '.','a','n','x',' ','0','1',';','3','5',0,
+  '.','o','g','v',' ','0','1',';','3','5',0,
+  '.','o','g','x',' ','0','1',';','3','5',0,
   '#',' ','a','u','d','i','o',' ','f','o','r','m','a','t','s',0,
   '.','a','a','c',' ','0','0',';','3','6',0,
   '.','a','u',' ','0','0',';','3','6',0,
@@ -169,4 +179,9 @@ static char const G_line[] =
   '.','o','g','g',' ','0','0',';','3','6',0,
   '.','r','a',' ','0','0',';','3','6',0,
   '.','w','a','v',' ','0','0',';','3','6',0,
+  '#',' ','h','t','t','p',':','/','/','w','i','k','i','.','x','i','p','h','.','o','r','g','/','i','n','d','e','x','.','p','h','p','/','M','I','M','E','_','T','y','p','e','s','_','a','n','d','_','F','i','l','e','_','E','x','t','e','n','s','i','o','n','s',0,
+  '.','a','x','a',' ','0','0',';','3','6',0,
+  '.','o','g','a',' ','0','0',';','3','6',0,
+  '.','s','p','x',' ','0','0',';','3','6',0,
+  '.','x','s','p','f',' ','0','0',';','3','6',0,
 };
