@@ -1,5 +1,5 @@
 /* du -- summarize disk usage
-   Copyright (C) 1988-1991, 1995-2007 Free Software Foundation, Inc.
+   Copyright (C) 1988-1991, 1995-2008 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -35,7 +35,6 @@
 #include "fprintftime.h"
 #include "hash.h"
 #include "human.h"
-#include "inttostr.h"
 #include "quote.h"
 #include "quotearg.h"
 #include "readtokens0.h"
@@ -50,7 +49,10 @@ extern bool fts_debug;
 #define PROGRAM_NAME "du"
 
 #define AUTHORS \
-  "Torbjorn Granlund", "David MacKenzie, Paul Eggert", "Jim Meyering"
+  proper_name_utf8 ("Torbjorn Granlund", "Torbj\303\266rn Granlund"), \
+  proper_name ("David MacKenzie"), \
+  proper_name ("Paul Eggert"), \
+  proper_name ("Jim Meyering")
 
 #if DU_DEBUG
 # define FTS_CROSS_CHECK(Fts) fts_cross_check (Fts)
@@ -123,9 +125,6 @@ struct dulevel
   struct duinfo subdir;
 };
 
-/* Name under which this program was invoked.  */
-char *program_name;
-
 /* If true, display counts for all files, not just directories.  */
 static bool opt_all = false;
 
@@ -312,9 +311,9 @@ Mandatory arguments to long options are mandatory for short options too.\n\
   -s, --summarize       display only a total for each argument\n\
 "), stdout);
       fputs (_("\
-  -x, --one-file-system  skip directories on different file systems\n\
-  -X FILE, --exclude-from=FILE  Exclude files that match any pattern in FILE.\n\
-      --exclude=PATTERN  Exclude files that match PATTERN.\n\
+  -x, --one-file-system    skip directories on different file systems\n\
+  -X, --exclude-from=FILE  exclude files that match any pattern in FILE\n\
+      --exclude=PATTERN    exclude files that match PATTERN\n\
       --max-depth=N     print the total for a directory (or file, with --all)\n\
                           only if it is N or fewer levels below the command\n\
                           line argument;  --max-depth=0 is the same as\n\
@@ -413,10 +412,7 @@ show_date (const char *format, struct timespec when)
   if (! tm)
     {
       char buf[INT_BUFSIZE_BOUND (intmax_t)];
-      error (0, 0, _("time %s is out of range"),
-	     (TYPE_SIGNED (time_t)
-	      ? imaxtostr (when.tv_sec, buf)
-	      : umaxtostr (when.tv_sec, buf)));
+      error (0, 0, _("time %s is out of range"), timetostr (when.tv_sec, buf));
       fputs (buf, stdout);
       return;
     }
@@ -479,7 +475,7 @@ process_file (FTS *fts, FTSENT *ent)
   bool skip;
 
   /* If necessary, set FTS_SKIP before returning.  */
-  skip = excluded_file_name (exclude, ent->fts_path);
+  skip = excluded_file_name (exclude, file);
   if (skip)
     fts_set (fts, ent, FTS_SKIP);
 
@@ -682,7 +678,7 @@ main (int argc, char **argv)
   cwd_only[1] = NULL;
 
   initialize_main (&argc, &argv);
-  program_name = argv[0];
+  set_program_name (argv[0]);
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
@@ -937,7 +933,7 @@ main (int argc, char **argv)
 	{
 	  error (0, 0, _("extra operand %s"), quote (argv[optind]));
 	  fprintf (stderr, "%s\n",
-		   _("File operands cannot be combined with --files0-from."));
+		   _("file operands cannot be combined with --files0-from"));
 	  usage (EXIT_FAILURE);
 	}
 
@@ -977,10 +973,22 @@ main (int argc, char **argv)
 	if ( ! files[i])
 	  break;
 
+	if (files_from && STREQ (files_from, "-") && STREQ (files[i], "-"))
+	  {
+	    /* Give a better diagnostic in an unusual case:
+	       printf - | du --files0-from=- */
+	    error (0, 0, _("when reading file names from stdin, "
+			   "no file name of %s allowed"),
+		   quote ("-"));
+	    continue;
+	  }
+
 	if (files[i][0])
 	  i++;
 	else
 	  {
+	    /* Diagnose a zero-length file name.  When it's one
+	       among many, knowing the record number may help.  */
 	    if (files_from)
 	      {
 		/* Using the standard `filename:line-number:' prefix here is
