@@ -35,12 +35,10 @@
 
 /* I wrote this program from scratch, based on the description of
    D.J. Bernstein's program: http://cr.yp.to/daemontools/setuidgid.html.  */
-#define AUTHORS "Jim Meyering"
+#define AUTHORS proper_name ("Jim Meyering")
 
 #define SETUIDGID_FAILURE 111
 
-char *program_name;
-
 void
 usage (int status)
 {
@@ -84,7 +82,7 @@ main (int argc, char **argv)
   gid_t primary_gid;
 
   initialize_main (&argc, &argv);
-  program_name = argv[0];
+  set_program_name (argv[0]);
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
@@ -92,7 +90,7 @@ main (int argc, char **argv)
   initialize_exit_failure (SETUIDGID_FAILURE);
   atexit (close_stdout);
 
-  parse_long_options (argc, argv, PROGRAM_NAME, PACKAGE_NAME, VERSION,
+  parse_long_options (argc, argv, PROGRAM_NAME, PACKAGE_NAME, Version,
                       usage, AUTHORS, (char const *) NULL);
   {
     int c;
