@@ -115,6 +115,7 @@ you must include <sys/types.h> before including this file
 
 #include <stdbool.h>
 #include <stdlib.h>
+#include "version.h"
 
 /* Exit statuses for programs like 'env' that exec other programs.  */
 enum
@@ -454,10 +455,19 @@ enum
 #include "closein.h"
 #include "closeout.h"
 #include "version-etc.h"
+#include "propername.h"
+/* Define away proper_name (leaving proper_name_utf8, which affects far
+   fewer programs), since it's not worth the cost of adding ~17KB to
+   the x86_64 text size of every single program.  This avoids a 40%
+   (almost ~2MB) increase in the on-disk space utilization for the set
+   of the 100 binaries. */
+#define proper_name(x) (x)
+
+#include "progname.h"
 
 #define case_GETOPT_VERSION_CHAR(Program_name, Authors)			\
   case GETOPT_VERSION_CHAR:						\
-    version_etc (stdout, Program_name, PACKAGE_NAME, VERSION, Authors,	\
+    version_etc (stdout, Program_name, PACKAGE_NAME, Version, Authors,	\
                  (char *) NULL);					\
     exit (EXIT_SUCCESS);						\
     break;
@@ -610,3 +620,13 @@ emit_bug_reporting_address (void)
      bugs (typically your translation team's web or email address).  */
   printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
 }
+
+#include "inttostr.h"
+
+static inline char *
+timetostr (time_t t, char *buf)
+{
+  return (TYPE_SIGNED (time_t)
+	  ? imaxtostr (t, buf)
+	  : umaxtostr (t, buf));
+}
