@@ -39,7 +39,6 @@
 
 #include "system.h"
 #include "euidaccess.h"
-#include "inttostr.h"
 #include "quote.h"
 #include "stat-time.h"
 #include "strnumcmp.h"
@@ -48,8 +47,6 @@
 # include <sys/param.h>
 #endif
 
-char *program_name;
-
 /* Exit status for syntax errors, etc.  */
 enum { TEST_TRUE, TEST_FALSE, TEST_FAILURE };
 
@@ -809,7 +806,7 @@ main (int margc, char **margv)
     return (test_error_return);
 #else /* TEST_STANDALONE */
   initialize_main (&margc, &margv);
-  program_name = margv[0];
+  set_program_name (margv[0]);
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
@@ -829,7 +826,7 @@ main (int margc, char **margv)
 	 to exit silently with status 0.  */
       if (margc < 2 || !STREQ (margv[margc - 1], "]"))
 	{
-	  parse_long_options (margc, margv, PROGRAM_NAME, PACKAGE_NAME, VERSION,
+	  parse_long_options (margc, margv, PROGRAM_NAME, PACKAGE_NAME, Version,
 			      usage, AUTHORS, (char const *) NULL);
 	  test_syntax_error (_("missing `]'"), NULL);
 	}
