@@ -27,7 +27,6 @@
 
 #include "system.h"
 #include "error.h"
-#include "inttostr.h"
 #include "mbchar.h"
 #include "quote.h"
 #include "quotearg.h"
@@ -49,9 +48,6 @@
 /* Size of atomic reads. */
 #define BUFFER_SIZE (16 * 1024)
 
-/* The name this program was run with. */
-char *program_name;
-
 /* Cumulative number of lines, words, chars and bytes in all files so far.
    max_line_length is the maximum over all files processed so far.  */
 static uintmax_t total_lines;
@@ -589,7 +585,7 @@ main (int argc, char **argv)
   struct Tokens tok;
 
   initialize_main (&argc, &argv);
-  program_name = argv[0];
+  set_program_name (argv[0]);
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
@@ -649,7 +645,7 @@ main (int argc, char **argv)
 	{
 	  error (0, 0, _("extra operand %s"), quote (argv[optind]));
 	  fprintf (stderr, "%s\n",
-		   _("File operands cannot be combined with --files0-from."));
+		   _("file operands cannot be combined with --files0-from"));
 	  usage (EXIT_FAILURE);
 	}
 
